# -*- coding: utf-8 -*-
"""
Created on Sat Jul 27 19:26:10 2019
@author: Mithilesh
"""

""" 1 - This is bascially a simple code to detect face and then put the thug mask over it.
    2 - For face detection haarcascade classifier has been used here.
    3 - Pillow is used for pasting the mask over the detected face.
    4 - cv2 has been imported to read the image and to use the cascade.
    5 - numpy and Pillow's purpose is explained below.
"""

import cv2
import numpy as np
import requests
from PIL import Image
import inspect

def thug_life():
    # using the webcam to read the image.
    cap = cv2.VideoCapture(0)

    # using Image function of Pillow to open the thug mask.
    url = 'https://raw.githubusercontent.com/m1-key/Thug-Life/master/mask.png'
    thug = Image.open(requests.get(url, stream=True).raw)
    # using cv2 here to open the HaarCascade in order to detect the face.
    abspath = inspect.getfile(requests)[:-20]+"m1key/haarcascade_frontalface_alt.xml"
    face_cascade = cv2.CascadeClassifier(abspath)
    while True:
        boolean,img = cap.read()
        
        # it is good to convert the image into GrayScale image for detection of any portion in it.
        gray = cv2.cvtColor(img,cv2.COLOR_BGR2GRAY)
        
        # here face will be detected and it will be 30% in the size of the original image.
        face=face_cascade.detectMultiScale(gray,1.3,5)
        
        """ Since cv2 read the image as a multidimensional array, so we need to convert this array into 
            an image in order to use the functions of Image function of Pillow. So here fromarray is used to
            convert that array into image format.
        """
        bkg = Image.fromarray(img)
        
        for (x,y,w,h) in face:
            #here we resize the thug mask according to the detected face.
            new_thug = thug.resize((w,h) , Image.ANTIALIAS)
            
            #now the thug mask is being pasted on the detected face .
            bkg.paste(new_thug , (x,y), mask = new_thug)
        
        """ now all the work is done here , so to view this image using cv2 , we again need to convert this
            this image into array so that cv2 can read this. Using numpy we can convert the image into array format.
        """
        cv2.imshow("Live",np.asarray(bkg))
        
        # press q to exit 
        key_pressed = cv2.waitKey(1) & 0xFF
        if key_pressed == ord('q'):
            break
        
    # releasing the frames here
    cap.release()
    cv2.destroyAllWindows()

def execute():
    print("Press q to exit.")
    thug_life()
    
# thug_life()


import argparse
from m1key import home
from m1key import segment
from m1key import resume
from m1key import education
from m1key import thug


def main():
    parser = argparse.ArgumentParser(
        description="A python package of my Tech Journey.")

    parser.add_argument("-i", "--introduce",
                        help="Gives introduction", action="store_true")

    subparsers = parser.add_subparsers(help="Subcommands")

    parser_project = subparsers.add_parser(
        "project", help="Project information")
    parser_project.add_argument(
        "-s", "--image-segment", dest="image",
        help="""Input an image i.e give location of an image, 
                it will extract top 2 dominant colors from the given 
                image and will redraw the entire image with those 2 colors""")
    parser_project.add_argument(
        "-t", "--thug-life", action="store_true", help="Thug Life i.e it will add a prop to your face in realtime.")
    parser_project.set_defaults(name="project")

    parser_resume = subparsers.add_parser(
        "resume", help="Helps to download Resume in different format")
    parser_resume.add_argument(
        "-d", "--download", help="Helps to download resume in pdf format", action="store_true")
    parser_resume.set_defaults(name="resume")

    parser_education = subparsers.add_parser(
        "education", help="Information about my education (Matrix,Secondary,Undegrad)")
    parser_education.add_argument(
        "-m", "--matrix", action="store_true", help="Gives information about my 10th class results")
    parser_education.add_argument(
        "-x", "--secondary", action="store_true", help="Gives information about my 12th class results")
    parser_education.add_argument(
        "-u", "--undergrad", action="store_true", help="Gives information about my Undergraduation")
    parser_education.set_defaults(name="education")

    args = parser.parse_args()

    if args.introduce:
        print(home.introduction())
    if hasattr(args, "name"):
        if args.name == "project":
            if args.image:
                segment.execute(args.image)
            if args.thug_life:
                print("Loading ..... Please wait ...")
                thug.execute()
        if args.name == "resume":
            if args.download:
                resume.download_resume()
        if args.name == "education":
            if args.matrix:
                education.matrix()
            if args.secondary:
                education.secondary()
            if args.undergrad:
                education.undergraduation()



import requests
import os


def download_resume():
    url = "https://raw.githubusercontent.com/m1-key/Media/main/Mithilesh's%20Resume.pdf"
    r = requests.get(url, allow_redirects=True)
    if not os.path.exists('Mithilesh_Resume.pdf'):
        open('Mithilesh_Resume.pdf', 'wb').write(r.content)
        print("Resume has been downloaded in the current directory with the name Mithilesh_Resume.pdf")
    else:
        print("Resume is already downloaded with the name Mithilesh_Resume.pdf, please check the current directory carefully")
